@@ -3,7 +3,7 @@ use 5.014;
 use warnings;
 use Carp qw(confess);
 
-$FASTX::Reader::VERSION = '0.20';
+$FASTX::Reader::VERSION = '0.31';
 #ABSTRACT: A lightweight module to parse FASTA and FASTQ files, based on Heng Li's readfq() method, packaged in an object oriented parser.
 
 use constant MAGIC_GZIP => pack('C3', 0x1f, 0x8b, 0x08);
@@ -73,7 +73,7 @@ sub getRead {
           return;
       }
   }
-  my ($name, $comm) = /^.(\S+)(?:\s+)(\S+)/ ? ($1, $2) : 
+  my ($name, $comm) = /^.(\S+)(?:\s+)(\S+)/ ? ($1, $2) :
 	                    /^.(\S+)/ ? ($1, '') : ('', '');
   #my $comm = /^.\S+\s+(.*)/? $1 : ''; # retain "comment"
   my $seq = '';
@@ -123,6 +123,7 @@ sub getFastqRead {
   my $seq    = readline($self->{fh});
   my $check  = readline($self->{fh});
   my $qual   = readline($self->{fh});
+  $self->{status} = 1;
 
   # Check 4 lines were found (FASTQ)
   return undef unless (defined $qual);
@@ -148,9 +149,9 @@ sub getFastqRead {
     }
   } else {
     # Return error (not a FASTQ)
-    $self->{message} = "Unknown format: expecting FASTQ (wrong header)";
+    $self->{message} = "Unknown format: expecting FASTQ but @ header not found";
 
-    if (substr($seq, 0,1 ) eq '>' ) {
+    if (substr($header, 0,1 ) eq '>' ) {
       # HINT: is FASTA?
       $self->{message} .= " (might be FASTA instead)";
     }
@@ -213,7 +214,7 @@ FASTX::Reader - A lightweight module to parse FASTA and FASTQ files, based on He
 
 =head1 VERSION
 
-version 0.20
+version 0.31
 
 =head1 SYNOPSIS
 
@@ -288,15 +289,19 @@ to retain I<sequence comments>.
 
 See: L<readfq repository|https://github.com/telatin/readfq>
 
+=item B<Fabrizio Levorin>
+
+has contributed to the prototyping of this module
+
 =back
 
-=head1 CONTRIBUTORS
+=head1 SEE ALSO
 
 =over 4
 
-=item B<Fabrizio Levorin>
+=item L<BioX::Seq::Stream>
 
-has substantially contributed to the development of this module, and is a collaborator in the GitHub repository
+The module I would have used if it was available when I started working on this
 
 =back
 
